# NoseXUnit: JUnit like XML reporting for PyUnit

NoseXUnit provide a convenient way to produce JUnit like XML reports with PyUnit.

## News

NoseXUnit is now compatible with Nose 0.10.0a2 and available via setuptools (uploaded on Python Cheese Shop).

## Backgroud

On the one hand, most of complex applications mix different languages and frameworks. On the other hand, test frameworks don't provide standard outputs. This makes difficult to generate an overall report of the tests for your aplication. However, some Java tests frameworks like JUnit with Surefire outputs convenient test report in a simple XML format. This makes further processing simple and convenient for softwares. For example, Bamboo creates interesting reports thanks these XML reports.

Our goal is to provide a way to produce test reports in this simple XML format with PyUnit.

## Install

NoseXUnit is a plugin for python-nose. Nose is a convenient way to play your PyUnit test.

Install NoseXUnit using setuptools:

    easy_install -U NoseXUnit

If setuptools is not installed, use the download link at right to download the source package, and install in the normal fashion. Untar the source package, step in the new directory, and:

    python setup.py install

If setuptools is already installed but too old, you may see an error like this:

> `The required version of setuptools (>=0.6c5) is not available, and can't be installed while this script is running. Please install a more recent version first.`

In that case, you'll need to update your setuptools install first by running:

    easy_install -U setuptools

or:

    python ez_setup.py -U setuptools

If nose is already installed but too old, you may see an error like this:

> `The required version of nose (>=0.10.0a2) is not available, and can't be installed while this script is running. Please install a more recent version first.`

In that case, you'll need to update your nose install first by running:

    easy_install -U nose

or:

    python ez_setup.py -U nose

## Nose Usage

See here.

## NoseXUnit Usage

NoseXUnit launch options can be display by running:

    nosetests --help

Four options are available:

    --with-nosexunit           Enable plugin NoseXUnit: Output XML report of test
                               status [NOSE_WITH_NOSEXUNIT]
    --xml-report-folder=REPORT
                               Folder to output XML report to
    --source-folder=SRC        Set the python's source folder, and add it in the path
    --recursive                Walk in the source folder to add deeper folders in the
                               path

## Bug reports

Please report bugs and make feature requests here.

## Changelog

0.2.0c1

- Compatibility with nose 0.10.0a2
- tb_info and capt removed from XTest (no more available with nose)
- Signature of addSuccess, addFailure and addError modified
- Entry point modification

0.2.0a1

- Compatibility with nose 0.10.0a1
- Create an XML output for each test module

0.1.0

- First version